%
% compute_rc_scale.m
% by Janet Slifka, Speech Communication Group, RLE, MIT
%
% Program to convert the rc_scale factor for respitrace measurements.
% This program takes as input the isovolume maneuvers and estimates the
% ribcage scale factor by fitting a line to the maneuver based on user
% selection of five points.
%

clear lstring;
tstring=['Data file: '];
colors=['r';'b';'c';'m';'g';'k';'y'];

count=1;

filename=input('Data file:\n','s');
load(filename)
fs=FS;
figure
tstring=[tstring,filename,' '];

plot(respirc,respiabd,colors(count))
hold on; grid on   
xlabel('Respitrace Ribcage (Volts)')
ylabel('Respitrace Abdomen (Volts)')

lstring(count,:)=sprintf('%s',filename);

title(tstring);
legend(lstring);

disp('Select five points from one of the isovolumes: ')
cpts=ginput(5);

coeffs=polyfit(cpts(:,1),cpts(:,2),1);
%rc_scale=abs(coeffs(1));
disp(['Slope = ',num2str(coeffs(1))]);

xmin=min(respirc)-0.2;
xmax=max(respirc)+0.2;
x=xmin:0.1:xmax;
y=polyval(coeffs,x);
h=plot(x,y,'k');
set(h,'LineWidth',2);
h=plot(cpts(:,1),cpts(:,2),'ko');
set(h,'LineWidth',2);
